Database
===============
``hckr`` supports various of database commands.

.. important::
   Before using these commands you need to add your database configuration in config (``.hckrcfg`` file), please refer :ref:`Configuring your database <configuration>`

.. tip::
   More commands will be added in future updates. Stay tuned!

commands
---------------
.. toctree::
    db

